@@ -13,6 +13,8 @@ import time
 import json
 import datetime
 
+from FastCNN.utils.CallBacks import MACallBack
+
 from tensorflow.keras.layers import Conv2D, BatchNormalization, Activation, MaxPool2D, Dropout, Flatten, Dense
 
 projpath = r"D:/FastCNN/Projects/GongDa"
@@ -264,7 +266,8 @@ def train(tag = None):
     if not tag:
         tag = datetime.datetime.strftime(datetime.datetime.now(),'%y%m%d_%H%M%S')
     
-    classify = getClassify(tag)
+    classify = getClassify(tag+"_train")
+    classify = getClassify(tag+"_valid")
     
     for dis in classify:
         
@@ -277,7 +280,7 @@ def train(tag = None):
         test_label += label
     
     train_batch = get_train_batch(train_data,train_label,32,150,150,"bmp")
-    test_batch = get_train_batch(test_data,test_label,32,150,150,"bmp")
+    test_batch = get_train_batch(test_data,test_label,1,150,150,"bmp")
     
     
     model = Baseline()
@@ -291,12 +294,15 @@ def train(tag = None):
     train_acc = tf.keras.metrics.SparseCategoricalAccuracy(name='train_acc')
     test_acc = tf.keras.metrics.SparseCategoricalAccuracy(name='test_acc')
     
+    """
     cp_callback = tf.keras.callbacks.ModelCheckpoint(filepath=checkpoint_save_path,
                                                         #save_freq='epoch',
                                                         period = 1,
                                                         save_weights_only=True,
                                                         save_best_only=True)
-        
+    """
+    
+    
     tensorboard = tf.keras.callbacks.TensorBoard(log_dir,histogram_freq=0)
     
     adam = tf.keras.optimizers.Adam(lr=0.0000001)
@@ -305,17 +311,22 @@ def train(tag = None):
               loss=tf.keras.losses.SparseCategoricalCrossentropy(from_logits=False),
               metrics=['sparse_categorical_accuracy'])
     
+    ma_callback = MACallBack()
+    ma_callback.init("GongDa",tag,model)
+    
     model.run_eagerly = True
     
     result = model.fit_generator(generator=get_train_batch(train_data,train_label,32,150,150,"bmp"), 
           steps_per_epoch=10, 
           epochs=10000, verbose=1,
           validation_data=test_batch,
-          validation_steps=20,
+          validation_steps=1,
           #validation_freq = 1,
-          callbacks=[cp_callback, tensorboard],
+          callbacks=[ma_callback],
           max_queue_size=128,
           workers=1)
+    
+    
     model.summary()
 
 def predictDirectory(dirtag,modeltag):
